Index: trunk/psLib/test/image/tst_psImageFFT.c
===================================================================
--- trunk/psLib/test/image/tst_psImageFFT.c	(revision 1984)
+++ trunk/psLib/test/image/tst_psImageFFT.c	(revision 2078)
@@ -6,6 +6,6 @@
  *  @author Robert DeSonia, MHPCC
  *
- *  @version $Revision: 1.10 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2004-10-06 21:40:13 $
+ *  @version $Revision: 1.11 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2004-10-13 19:50:12 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -192,35 +192,11 @@
     }
 
     /* Verify return null and program execution doesn't stop if input image is invalid type */
     GENIMAGE(img4,8,8,S8,row+col);
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate error for invalid input image type.");
-    img5 = psImageFFT(NULL,img4,PS_FFT_FORWARD);
+    psLogMsg(__func__,PS_LOG_INFO,"Following should generate error for invalid direction.");
+    img5 = psImageFFT(NULL,img4,PS_FFT_REAL_RESULT);
     if (img5 != NULL) {
-        psError(__func__,"psImageFFT should return null for an invalid type image.");
+        psError(__func__,"psImageFFT should return null for an invalid FFT direction.");
         return 11;
-    }
-    psFree(img4);
-
-    /* Verify return null and program execution doesn't stop if input image F32 but
-       reverse FFT operation specified.
-    */
-    GENIMAGE(img4,8,8,F32,row+col);
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate error for F32 reverse FFT operation.");
-    img5 = psImageFFT(NULL,img4,PS_FFT_REVERSE);
-    if (img5 != NULL) {
-        psError(__func__,"psImageFFT should return null for F32 input with reverse FFT operation.");
-        return 12;
-    }
-    psFree(img4);
-
-    /* Verify return null and program execution doesn't stop if input image C32 but
-       forward FFT operation specified.
-    */
-    GENIMAGE(img4,8,8,C32,row+col);
-    psLogMsg(__func__,PS_LOG_INFO,"Following should generate error for C32 forward FFT operation.");
-    img5 = psImageFFT(NULL,img4,PS_FFT_FORWARD);
-    if (img5 != NULL) {
-        psError(__func__,"psImageFFT should return null for C32 input with forward FFT operation.");
-        return 13;
     }
     psFree(img4);
@@ -192,35 +192,11 @@
     }
 
-    /* Verify return null and program execution doesn't stop if input image is invalid type */
+    /* Verify return null and program execution doesn't stop if input image is invalid direction */
     GENIMAGE(img4,8,8,S8,row+col);
